==> slapos.cookbook-0.38.tar.gz: slapos.cookbook-0.38/slapos/recipe/mkdirectory.py <==
##############################################################################
#
# Copyright (c) 2010 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
import os

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

  def _options(self, options):
    self.directory = options.copy()
    del self.directory['recipe']

    str_mode = '0700'
    if 'mode' in self.directory:
      str_mode = self.directory['mode']
      del self.directory['mode']
    self.mode = int(str_mode, 8)

  def install(self):

    for directory in self.directory.values():
      path = directory

      if not os.path.exists(path):
        os.mkdir(path, self.mode)
      elif not os.path.isdir(path):
        raise OSError("%s path exits, but it's not a directory.")

    return []

==> slapos.cookbook-0.40.1.tar.gz: slapos.cookbook-0.40.1/slapos/recipe/mkdirectory.py <==
##############################################################################
#
# Copyright (c) 2010 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
import os

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

  def _options(self, options):
    self.directory = options.copy()
    del self.directory['recipe']

    str_mode = '0700'
    if 'mode' in self.directory:
      str_mode = self.directory['mode']
      del self.directory['mode']
    self.mode = int(str_mode, 8)

  def install(self):

    for directory in sorted(self.directory.values()):
      path = directory

      if not os.path.exists(path):
        os.mkdir(path, self.mode)
      elif not os.path.isdir(path):
        raise OSError("%s path exits, but it's not a directory.")

    return []
